summaryrefslogtreecommitdiffstats
path: root/akregator/src/tagaction.h
diff options
context:
space:
mode:
Diffstat (limited to 'akregator/src/tagaction.h')
-rw-r--r--akregator/src/tagaction.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/akregator/src/tagaction.h b/akregator/src/tagaction.h
index 59ea3ccb..b869f9ec 100644
--- a/akregator/src/tagaction.h
+++ b/akregator/src/tagaction.h
@@ -34,8 +34,8 @@ namespace Akregator {
class Tag;
-/** a KToggleAction for assigning and removing tags. Displays the tag name and emits the tag when activated */
-class TagAction : public KToggleAction
+/** a TDEToggleAction for assigning and removing tags. Displays the tag name and emits the tag when activated */
+class TagAction : public TDEToggleAction
{
Q_OBJECT